#!/usr/bin/sh

# Check if we have Postfix at all. If not, then bugger out.
if [ ! -d '/etc/postfix' ];then
    echo "ERROR: Postfix directory /etc/postfix not found!"
    exit
fi

# Create config directory for milter-configs:
if [ ! -d /etc/postfix/milters.d ];then
    mkdir -p /etc/postfix/milters.d
    chown root:root /etc/postfix/milters.d
    chmod 644 /etc/postfix/milters.d
fi

# Check if Postfix is running:
POSTFIXUP=$(LC_ALL=C systemctl status postfix|grep " Active: active (running)"|wc -l)

# Check if Postfix Systemd Unit-File has our ExecStartPre for /usr/sausalito/bin/blueonyx-postfix
# If not, then create a new Postfix Systemd Unit-File:
if [ -f '/usr/lib/systemd/system/postfix.service' ];then
    UNITFILEBX=$(cat /usr/lib/systemd/system/postfix.service|grep blueonyx-postfix|wc -l)
    if [ "$UNITFILEBX" -eq "0" ];then
        echo "[Unit]" > /usr/lib/systemd/system/postfix.service
        echo "Description=Postfix Mail Transport Agent" >> /usr/lib/systemd/system/postfix.service
        echo "After=syslog.target network.target" >> /usr/lib/systemd/system/postfix.service
        echo "Conflicts=sendmail.service exim.service" >> /usr/lib/systemd/system/postfix.service
        echo "" >> /usr/lib/systemd/system/postfix.service
        echo "[Service]" >> /usr/lib/systemd/system/postfix.service
        echo "Type=forking" >> /usr/lib/systemd/system/postfix.service
        echo "PIDFile=/var/spool/postfix/pid/master.pid" >> /usr/lib/systemd/system/postfix.service
        echo "EnvironmentFile=-/etc/sysconfig/network" >> /usr/lib/systemd/system/postfix.service
        echo "PrivateTmp=true" >> /usr/lib/systemd/system/postfix.service
        echo "CapabilityBoundingSet=~ CAP_NET_ADMIN CAP_SYS_ADMIN CAP_SYS_BOOT CAP_SYS_MODULE" >> /usr/lib/systemd/system/postfix.service
        echo "ProtectSystem=true" >> /usr/lib/systemd/system/postfix.service
        echo "PrivateDevices=true" >> /usr/lib/systemd/system/postfix.service
        echo "ExecStartPre=-/usr/sausalito/bin/blueonyx-postfix" >> /usr/lib/systemd/system/postfix.service
        echo "ExecStartPre=-/usr/libexec/postfix/aliasesdb" >> /usr/lib/systemd/system/postfix.service
        echo "ExecStartPre=-/usr/libexec/postfix/chroot-update" >> /usr/lib/systemd/system/postfix.service
        echo "ExecStart=/usr/sbin/postfix start" >> /usr/lib/systemd/system/postfix.service
        echo "ExecReload=/usr/sbin/postfix reload" >> /usr/lib/systemd/system/postfix.service
        echo "ExecStop=/usr/sbin/postfix stop" >> /usr/lib/systemd/system/postfix.service
        echo "" >> /usr/lib/systemd/system/postfix.service
        echo "[Install]" >> /usr/lib/systemd/system/postfix.service
        echo "WantedBy=multi-user.target" >> /usr/lib/systemd/system/postfix.service
        echo "" >> /usr/lib/systemd/system/postfix.service

        # Systemd reload:
        /usr/bin/systemctl daemon-reload >/dev/null 2>&1 || :

        # Perform Postfix restart:
        if [ "$POSTFIXUP" -eq "1" ];then
            /usr/bin/systemctl restart postfix >/dev/null 2>&1 || :
        fi
    fi
fi

#
### Get basic GUI configured MTA options from Sendmail config and apply them to Postfix:
#

postconf -e 'mailbox_size_limit = 1000000000000'

# Submission port:
SUBMISSION=$(cat /etc/mail/sendmail.mc|grep DAEMON_OPTIONS|grep Port=submission|grep dnl|wc -l)
if [ "$SUBMISSION" -eq "0" ];then
    sed -i 's@^#submission inet n       -       n       -       -       smtpd$@submission inet n       -       n       -       -       smtpd@g' /etc/postfix/master.cf
else
    sed -i 's@^submission inet n       -       n       -       -       smtpd$@#submission inet n       -       n       -       -       smtpd@g' /etc/postfix/master.cf
fi

DOM=$(/usr/bin/hostname --domain)
HN=$(/usr/bin/hostname)
NW=$(ip -o -f inet addr show | awk '/scope global/ {print $4}')
postconf -e "mydomain = $DOM"
postconf -e "myhostname = $HN"
postconf -e "mynetworks = 127.0.0.0/8 127.0.0.1/32 [::1]/128 $NW"

MAX_MESSAGE_SIZE=$(LC_ALL=C cat /etc/mail/sendmail.mc |grep confMAX_MESSAGE_SIZE|cut -d , -f2|cut -d \) -f1)
if [ "$MAX_MESSAGE_SIZE" -eq "0" ] || [ "$MAX_MESSAGE_SIZE" = "" ];then
    MAX_MESSAGE_SIZE=102400000
fi
postconf -e "message_size_limit = $MAX_MESSAGE_SIZE"

MAX_RCPTS_PER_MESSAGE=$(cat /etc/mail/sendmail.mc |grep confMAX_RCPTS_PER_MESSAGE|cut -d , -f2|cut -d \) -f1)
if [ "$MAX_RCPTS_PER_MESSAGE" -eq "0" ] || [ "$MAX_RCPTS_PER_MESSAGE" = "" ];then
    MAX_RCPTS_PER_MESSAGE=50
fi
postconf -e "default_destination_recipient_limit = $MAX_RCPTS_PER_MESSAGE"
postconf -e "smtp_destination_recipient_limit = $MAX_RCPTS_PER_MESSAGE"

RELAY=$(cat /etc/mail/sendmail.mc |grep SMART_HOST|cut -d \` -f3|cut -d \' -f1)
if [ "$RELAY" = "" ];then
    postconf -e 'relayhost ='
else 
    postconf -e "relayhost = $RELAY"
fi

# Handle RBL Blacklists:
HAVEVBL=$(cat /etc/mail/sendmail.mc |grep dnsbl|grep -v dnl|wc -l)
if [ "$HAVEVBL" -gt "0" ];then
    RBLS=$(cat /etc/mail/sendmail.mc |grep dnsbl|grep -v dnl|cut -d \` -f 2|cut -d \' -f1| tr '\n' ', '|sed 's@,$@@g')
    postconf -e "postscreen_dnsbl_sites = $RBLS"
    postconf -e 'postscreen_dnsbl_action = enforce'
else
    postconf -e "postscreen_dnsbl_sites ="
    postconf -e 'postscreen_dnsbl_action = ignore'
fi

# Set ACL's:
postconf -e 'smtpd_recipient_restrictions = permit_sasl_authenticated,reject_non_fqdn_sender,reject_non_fqdn_recipient,reject_unknown_sender_domain,reject_unknown_recipient_domain,permit_mynetworks,reject_unauth_destination,reject_unauth_pipelining,reject_invalid_hostname,reject_non_fqdn_hostname,check_sender_access hash:/etc/postfix/access,check_sender_access hash:/etc/postfix/suspended_users,permit'

# Set general BlueOnyx related settings such as maps, cert location, TLS and so on:
postconf -e 'inet_interfaces = all'
postconf -e 'inet_protocols = all'
postconf -e 'alias_maps = hash:/etc/mail/aliases, hash:/etc/mail/aliases.mailman'
postconf -e 'alias_database = $alias_maps'
postconf -e 'owner_request_special = yes'
postconf -e 'smtpd_use_tls = yes'
#postconf -e 'smtpd_tls_cert_file = /etc/admserv/certs/nginx_cert_ca_combined'
#postconf -e 'smtpd_tls_key_file = /etc/admserv/certs/key'
postconf -e 'smtpd_tls_security_level = may'
postconf -e 'smtpd_tls_mandatory_ciphers = high'
postconf -e 'smtpd_tls_mandatory_protocols = !SSLv2, !SSLv3'
postconf -e 'smtpd_tls_loglevel = 1'
postconf -e 'smtpd_tls_received_header = yes'
postconf -e 'smtp_use_tls=yes'
postconf -e 'smtp_tls_CApath = /etc/pki/tls/certs'
postconf -e 'smtp_tls_CAfile = /etc/pki/tls/certs/ca-bundle.crt'
postconf -e 'smtp_tls_mandatory_ciphers=high'
postconf -e 'smtp_tls_mandatory_protocols = !SSLv2, !SSLv3'
postconf -e 'smtp_tls_note_starttls_offer = yes'
postconf -e 'mailbox_command = /usr/bin/procmail -a "$EXTENSION"'
postconf -e 'disable_vrfy_command = yes'
postconf -e 'smtpd_helo_required = yes'
postconf -e 'smtpd_sender_restrictions = reject_unknown_sender_domain'
postconf -e 'smtpd_client_restrictions = sleep 5'
postconf -e 'smtpd_delay_reject = yes'
postconf -e 'smtpd_error_sleep_time = 30'
postconf -e 'smtpd_soft_error_limit = 10'
postconf -e 'strict_rfc821_envelopes = yes'
postconf -e 'header_checks = regexp:/etc/postfix/header_checks'
postconf -e 'smtpd_sasl_auth_enable = yes'
postconf -e 'smtpd_sasl_authenticated_header = yes'
postconf -e 'smtpd_sasl_security_options = noanonymous'
postconf -e 'smtpd_sasl_type = cyrus'
postconf -e 'virtual_alias_domains = /etc/mail/local-host-names'
postconf -e 'virtual_alias_maps = hash:/etc/mail/aliases, hash:/etc/postfix/virtual, hash:/etc/mail/aliases.mailman'
postconf -e 'canonical_maps = hash:/etc/postfix/canonical'
postconf -e 'milter_default_action = accept'
postconf -e 'milter_connect_macros = H, j, _, {daemon_name}, {daemon_port}, {if_name}, {if_addr}, {client_addr}'
postconf -e 'milter_protocol = 6'

# Activate SNI:
if [ ! -f /etc/postfix/vsite_ssl.map ];then
    touch /etc/postfix/vsite_ssl.map
    postmap -F hash:/etc/postfix/vsite_ssl.map
fi
postconf -e 'smtpd_tls_chain_files = /etc/admserv/certs/key /etc/admserv/certs/nginx_cert_ca_combined'
postconf -e 'tls_server_sni_maps = hash:/etc/postfix/vsite_ssl.map'

#
### Set the rest of the Postfix configuration to sane defaults - provided they were never set in first place:
#

# And yes: Currently these aren't applied ever and we leave the defaults.

INITIALCFGDONE=$(cat /etc/postfix/main.cf|grep /etc/mail/aliases.mailman|wc -l)
if [ "$INITIALCFGDONE" -eq "0" ];then
    postconf -e '2bounce_notice_recipient = postmaster'
    postconf -e 'access_map_defer_code = 450'
    postconf -e 'access_map_reject_code = 554'
    postconf -e 'address_verify_cache_cleanup_interval = 12h'
    postconf -e 'address_verify_default_transport = $default_transport'
    postconf -e 'address_verify_local_transport = $local_transport'
    postconf -e 'address_verify_map = btree:$data_directory/verify_cache'
    postconf -e 'address_verify_negative_cache = yes'
    postconf -e 'address_verify_negative_expire_time = 3d'
    postconf -e 'address_verify_negative_refresh_time = 3h'
    postconf -e 'address_verify_pending_request_limit = 5000'
    postconf -e 'address_verify_poll_count = ${stress?{1}:{3}}'
    postconf -e 'address_verify_poll_delay = 3s'
    postconf -e 'address_verify_positive_expire_time = 31d'
    postconf -e 'address_verify_positive_refresh_time = 7d'
    postconf -e 'address_verify_relay_transport = $relay_transport'
    postconf -e 'address_verify_relayhost = $relayhost'
    postconf -e 'address_verify_sender = $double_bounce_sender'
    postconf -e 'address_verify_sender_dependent_default_transport_maps = $sender_dependent_default_transport_maps'
    postconf -e 'address_verify_sender_dependent_relayhost_maps = $sender_dependent_relayhost_maps'
    postconf -e 'address_verify_sender_ttl = 0s'
    postconf -e 'address_verify_service_name = verify'
    postconf -e 'address_verify_transport_maps = $transport_maps'
    postconf -e 'address_verify_virtual_transport = $virtual_transport'
    postconf -e 'allow_mail_to_commands = alias, forward'
    postconf -e 'allow_mail_to_files = alias, forward'
    postconf -e 'allow_min_user = no'
    postconf -e 'allow_percent_hack = yes'
    postconf -e 'allow_untrusted_routing = no'
    postconf -e 'alternate_config_directories ='
    postconf -e 'always_add_missing_headers = no'
    postconf -e 'always_bcc ='
    postconf -e 'anvil_rate_time_unit = 60s'
    postconf -e 'anvil_status_update_time = 600s'
    postconf -e 'append_at_myorigin = yes'
    postconf -e 'append_dot_mydomain = ${{$compatibility_level} < {1} ? {yes} : {no}}'
    postconf -e 'application_event_drain_time = 100s'
    postconf -e 'authorized_flush_users = static:anyone'
    postconf -e 'authorized_mailq_users = static:anyone'
    postconf -e 'authorized_submit_users = static:anyone'
    postconf -e 'backwards_bounce_logfile_compatibility = yes'
    postconf -e 'berkeley_db_create_buffer_size = 16777216'
    postconf -e 'berkeley_db_read_buffer_size = 131072'
    postconf -e 'best_mx_transport ='
    postconf -e 'biff = yes'
    postconf -e 'body_checks ='
    postconf -e 'body_checks_size_limit = 51200'
    postconf -e 'bounce_notice_recipient = postmaster'
    postconf -e 'bounce_queue_lifetime = 5d'
    postconf -e 'bounce_service_name = bounce'
    postconf -e 'bounce_size_limit = 50000'
    postconf -e 'bounce_template_file ='
    postconf -e 'broken_sasl_auth_clients = no'
    postconf -e 'canonical_classes = envelope_sender, envelope_recipient, header_sender, header_recipient'
    postconf -e 'cleanup_service_name = cleanup'
    postconf -e 'command_directory = /usr/sbin'
    postconf -e 'command_execution_directory ='
    postconf -e 'command_expansion_filter = 1234567890!@%-_=+:,./abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ'
    postconf -e 'command_time_limit = 1000s'
    postconf -e 'compatibility_level = 0'
    postconf -e 'config_directory = /etc/postfix'
    postconf -e 'confirm_delay_cleared = no'
    postconf -e 'connection_cache_protocol_timeout = 5s'
    postconf -e 'connection_cache_service_name = scache'
    postconf -e 'connection_cache_status_update_time = 600s'
    postconf -e 'connection_cache_ttl_limit = 2s'
    postconf -e 'content_filter ='
    postconf -e 'cyrus_sasl_config_path ='
    postconf -e 'daemon_directory = /usr/libexec/postfix'
    postconf -e 'daemon_table_open_error_is_fatal = no'
    postconf -e 'daemon_timeout = 18000s'
    postconf -e 'data_directory = /var/lib/postfix'
    postconf -e 'debug_peer_level = 2'
    postconf -e 'debug_peer_list ='
    postconf -e 'debugger_command ='
    postconf -e 'default_database_type = hash'
    postconf -e 'default_delivery_slot_cost = 5'
    postconf -e 'default_delivery_slot_discount = 50'
    postconf -e 'default_delivery_slot_loan = 3'
    postconf -e 'default_delivery_status_filter ='
    postconf -e 'default_destination_concurrency_failed_cohort_limit = 1'
    postconf -e 'default_destination_concurrency_limit = 20'
    postconf -e 'default_destination_concurrency_negative_feedback = 1'
    postconf -e 'default_destination_concurrency_positive_feedback = 1'
    postconf -e 'default_destination_rate_delay = 0s'
    postconf -e 'default_extra_recipient_limit = 1000'
    postconf -e 'default_filter_nexthop ='
    postconf -e 'default_minimum_delivery_slots = 3'
    postconf -e 'default_privs = nobody'
    postconf -e 'default_process_limit = 100'
    postconf -e 'default_rbl_reply = $rbl_code Service unavailable; $rbl_class [$rbl_what] blocked using $rbl_domain${rbl_reason?; $rbl_reason}'
    postconf -e 'default_recipient_limit = 20000'
    postconf -e 'default_recipient_refill_delay = 5s'
    postconf -e 'default_recipient_refill_limit = 100'
    postconf -e 'default_transport = smtp'
    postconf -e 'default_transport_rate_delay = 0s'
    postconf -e 'default_verp_delimiters = +='
    postconf -e 'defer_code = 450'
    postconf -e 'defer_service_name = defer'
    postconf -e 'defer_transports ='
    postconf -e 'delay_logging_resolution_limit = 2'
    postconf -e 'delay_notice_recipient = postmaster'
    postconf -e 'delay_warning_time = 0h'
    postconf -e 'deliver_lock_attempts = 20'
    postconf -e 'deliver_lock_delay = 1s'
    postconf -e 'destination_concurrency_feedback_debug = no'
    postconf -e 'detect_8bit_encoding_header = yes'
    postconf -e 'disable_dns_lookups = no'
    postconf -e 'disable_mime_input_processing = no'
    postconf -e 'disable_mime_output_conversion = no'
    postconf -e 'disable_verp_bounces = no'
    postconf -e 'dns_ncache_ttl_fix_enable = no'
    postconf -e 'dnsblog_reply_delay = 0s'
    postconf -e 'dnsblog_service_name = dnsblog'
    postconf -e 'dont_remove = 0'
    postconf -e 'double_bounce_sender = double-bounce'
    postconf -e 'duplicate_filter_limit = 1000'
    postconf -e 'empty_address_default_transport_maps_lookup_key = <>'
    postconf -e 'empty_address_recipient = MAILER-DAEMON'
    postconf -e 'empty_address_relayhost_maps_lookup_key = <>'
    postconf -e 'enable_idna2003_compatibility = no'
    postconf -e 'enable_long_queue_ids = no'
    postconf -e 'enable_original_recipient = yes'
    postconf -e 'error_delivery_slot_cost = $default_delivery_slot_cost'
    postconf -e 'error_delivery_slot_discount = $default_delivery_slot_discount'
    postconf -e 'error_delivery_slot_loan = $default_delivery_slot_loan'
    postconf -e 'error_destination_concurrency_failed_cohort_limit = $default_destination_concurrency_failed_cohort_limit'
    postconf -e 'error_destination_concurrency_limit = $default_destination_concurrency_limit'
    postconf -e 'error_destination_concurrency_negative_feedback = $default_destination_concurrency_negative_feedback'
    postconf -e 'error_destination_concurrency_positive_feedback = $default_destination_concurrency_positive_feedback'
    postconf -e 'error_destination_rate_delay = $default_destination_rate_delay'
    postconf -e 'error_destination_recipient_limit = $default_destination_recipient_limit'
    postconf -e 'error_extra_recipient_limit = $default_extra_recipient_limit'
    postconf -e 'error_initial_destination_concurrency = $initial_destination_concurrency'
    postconf -e 'error_minimum_delivery_slots = $default_minimum_delivery_slots'
    postconf -e 'error_notice_recipient = postmaster'
    postconf -e 'error_recipient_limit = $default_recipient_limit'
    postconf -e 'error_recipient_refill_delay = $default_recipient_refill_delay'
    postconf -e 'error_recipient_refill_limit = $default_recipient_refill_limit'
    postconf -e 'error_service_name = error'
    postconf -e 'error_transport_rate_delay = $default_transport_rate_delay'
    postconf -e 'execution_directory_expansion_filter = 1234567890!@%-_=+:,./abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ'
    postconf -e 'expand_owner_alias = no'
    postconf -e 'export_environment = TZ MAIL_CONFIG LANG'
    postconf -e 'fallback_transport ='
    postconf -e 'fallback_transport_maps ='
    postconf -e 'fast_flush_domains = $relay_domains'
    postconf -e 'fast_flush_purge_time = 7d'
    postconf -e 'fast_flush_refresh_time = 12h'
    postconf -e 'fault_injection_code = 0'
    postconf -e 'flush_service_name = flush'
    postconf -e 'fork_attempts = 5'
    postconf -e 'fork_delay = 1s'
    postconf -e 'forward_expansion_filter = 1234567890!@%-_=+:,./abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ'
    postconf -e 'forward_path = $home/.forward${recipient_delimiter}${extension}, $home/.forward'
    postconf -e 'frozen_delivered_to = yes'
    postconf -e 'hash_queue_depth = 1'
    postconf -e 'hash_queue_names = deferred, defer'
    postconf -e 'header_address_token_limit = 10240'
    postconf -e 'header_from_format = standard'
    postconf -e 'header_size_limit = 102400'
    postconf -e 'helpful_warnings = yes'
    postconf -e 'home_mailbox ='
    postconf -e 'hopcount_limit = 50'
    postconf -e 'html_directory = no'
    postconf -e 'ignore_mx_lookup_error = no'
    postconf -e 'import_environment = MAIL_CONFIG MAIL_DEBUG MAIL_LOGTAG TZ XAUTHORITY DISPLAY LANG=C'
    postconf -e 'in_flow_delay = 1s'
    postconf -e 'initial_destination_concurrency = 5'
    postconf -e 'internal_mail_filter_classes ='
    postconf -e 'invalid_hostname_reject_code = 501'
    postconf -e 'ipc_idle = 5s'
    postconf -e 'ipc_timeout = 3600s'
    postconf -e 'ipc_ttl = 1000s'
    postconf -e 'line_length_limit = 2048'
    postconf -e 'lmdb_map_size = 16777216'
    postconf -e 'lmtp_address_preference = any'
    postconf -e 'lmtp_address_verify_target = rcpt'
    postconf -e 'lmtp_assume_final = no'
    postconf -e 'lmtp_balance_inet_protocols = yes'
    postconf -e 'lmtp_bind_address ='
    postconf -e 'lmtp_bind_address6 ='
    postconf -e 'lmtp_body_checks ='
    postconf -e 'lmtp_cname_overrides_servername = no'
    postconf -e 'lmtp_connect_timeout = 0s'
    postconf -e 'lmtp_connection_cache_destinations ='
    postconf -e 'lmtp_connection_cache_on_demand = yes'
    postconf -e 'lmtp_connection_cache_time_limit = 2s'
    postconf -e 'lmtp_connection_reuse_count_limit = 0'
    postconf -e 'lmtp_connection_reuse_time_limit = 300s'
    postconf -e 'lmtp_data_done_timeout = 600s'
    postconf -e 'lmtp_data_init_timeout = 120s'
    postconf -e 'lmtp_data_xfer_timeout = 180s'
    postconf -e 'lmtp_defer_if_no_mx_address_found = no'
    postconf -e 'lmtp_delivery_slot_cost = $default_delivery_slot_cost'
    postconf -e 'lmtp_delivery_slot_discount = $default_delivery_slot_discount'
    postconf -e 'lmtp_delivery_slot_loan = $default_delivery_slot_loan'
    postconf -e 'lmtp_delivery_status_filter = $default_delivery_status_filter'
    postconf -e 'lmtp_destination_concurrency_failed_cohort_limit = $default_destination_concurrency_failed_cohort_limit'
    postconf -e 'lmtp_destination_concurrency_limit = $default_destination_concurrency_limit'
    postconf -e 'lmtp_destination_concurrency_negative_feedback = $default_destination_concurrency_negative_feedback'
    postconf -e 'lmtp_destination_concurrency_positive_feedback = $default_destination_concurrency_positive_feedback'
    postconf -e 'lmtp_destination_rate_delay = $default_destination_rate_delay'
    postconf -e 'lmtp_destination_recipient_limit = $default_destination_recipient_limit'
    postconf -e 'lmtp_discard_lhlo_keyword_address_maps ='
    postconf -e 'lmtp_discard_lhlo_keywords ='
    postconf -e 'lmtp_dns_reply_filter ='
    postconf -e 'lmtp_dns_resolver_options ='
    postconf -e 'lmtp_dns_support_level ='
    postconf -e 'lmtp_enforce_tls = no'
    postconf -e 'lmtp_extra_recipient_limit = $default_extra_recipient_limit'
    postconf -e 'lmtp_fallback_relay ='
    postconf -e 'lmtp_generic_maps ='
    postconf -e 'lmtp_header_checks ='
    postconf -e 'lmtp_host_lookup = dns'
    postconf -e 'lmtp_initial_destination_concurrency = $initial_destination_concurrency'
    postconf -e 'lmtp_lhlo_name = $myhostname'
    postconf -e 'lmtp_lhlo_timeout = 300s'
    postconf -e 'lmtp_line_length_limit = 998'
    postconf -e 'lmtp_mail_timeout = 300s'
    postconf -e 'lmtp_mime_header_checks ='
    postconf -e 'lmtp_minimum_delivery_slots = $default_minimum_delivery_slots'
    postconf -e 'lmtp_mx_address_limit = 5'
    postconf -e 'lmtp_mx_session_limit = 2'
    postconf -e 'lmtp_nested_header_checks ='
    postconf -e 'lmtp_per_record_deadline = no'
    postconf -e 'lmtp_pix_workaround_delay_time = 10s'
    postconf -e 'lmtp_pix_workaround_maps ='
    postconf -e 'lmtp_pix_workaround_threshold_time = 500s'
    postconf -e 'lmtp_pix_workarounds = disable_esmtp,delay_dotcrlf'
    postconf -e 'lmtp_quit_timeout = 300s'
    postconf -e 'lmtp_quote_rfc821_envelope = yes'
    postconf -e 'lmtp_randomize_addresses = yes'
    postconf -e 'lmtp_rcpt_timeout = 300s'
    postconf -e 'lmtp_recipient_limit = $default_recipient_limit'
    postconf -e 'lmtp_recipient_refill_delay = $default_recipient_refill_delay'
    postconf -e 'lmtp_recipient_refill_limit = $default_recipient_refill_limit'
    postconf -e 'lmtp_reply_filter ='
    postconf -e 'lmtp_rset_timeout = 20s'
    postconf -e 'lmtp_sasl_auth_cache_name ='
    postconf -e 'lmtp_sasl_auth_cache_time = 90d'
    postconf -e 'lmtp_sasl_auth_enable = no'
    postconf -e 'lmtp_sasl_auth_soft_bounce = yes'
    postconf -e 'lmtp_sasl_mechanism_filter ='
    postconf -e 'lmtp_sasl_password_maps ='
    postconf -e 'lmtp_sasl_path ='
    postconf -e 'lmtp_sasl_security_options = noplaintext, noanonymous'
    postconf -e 'lmtp_sasl_tls_security_options = $lmtp_sasl_security_options'
    postconf -e 'lmtp_sasl_tls_verified_security_options = $lmtp_sasl_tls_security_options'
    postconf -e 'lmtp_sasl_type = cyrus'
    postconf -e 'lmtp_send_dummy_mail_auth = no'
    postconf -e 'lmtp_send_xforward_command = no'
    postconf -e 'lmtp_sender_dependent_authentication = no'
    postconf -e 'lmtp_skip_5xx_greeting = yes'
    postconf -e 'lmtp_skip_quit_response = no'
    postconf -e 'lmtp_starttls_timeout = 300s'
    postconf -e 'lmtp_tcp_port = 24'
    postconf -e 'lmtp_tls_CAfile ='
    postconf -e 'lmtp_tls_CApath ='
    postconf -e 'lmtp_tls_block_early_mail_reply = no'
    postconf -e 'lmtp_tls_cert_file ='
    postconf -e 'lmtp_tls_ciphers = medium'
    postconf -e 'lmtp_tls_dcert_file ='
    postconf -e 'lmtp_tls_dkey_file = $lmtp_tls_dcert_file'
    postconf -e 'lmtp_tls_eccert_file ='
    postconf -e 'lmtp_tls_eckey_file = $lmtp_tls_eccert_file'
    postconf -e 'lmtp_tls_enforce_peername = yes'
    postconf -e 'lmtp_tls_exclude_ciphers ='
    postconf -e 'lmtp_tls_fingerprint_cert_match ='
    postconf -e 'lmtp_tls_fingerprint_digest = md5'
    postconf -e 'lmtp_tls_force_insecure_host_tlsa_lookup = no'
    postconf -e 'lmtp_tls_key_file = $lmtp_tls_cert_file'
    postconf -e 'lmtp_tls_loglevel = 0'
    postconf -e 'lmtp_tls_mandatory_ciphers = medium'
    postconf -e 'lmtp_tls_mandatory_exclude_ciphers ='
    postconf -e 'lmtp_tls_mandatory_protocols = !SSLv2, !SSLv3'
    postconf -e 'lmtp_tls_note_starttls_offer = no'
    postconf -e 'lmtp_tls_per_site ='
    postconf -e 'lmtp_tls_policy_maps ='
    postconf -e 'lmtp_tls_protocols = !SSLv2, !SSLv3'
    postconf -e 'lmtp_tls_scert_verifydepth = 9'
    postconf -e 'lmtp_tls_secure_cert_match = nexthop'
    postconf -e 'lmtp_tls_security_level ='
    postconf -e 'lmtp_tls_session_cache_database ='
    postconf -e 'lmtp_tls_session_cache_timeout = 3600s'
    postconf -e 'lmtp_tls_trust_anchor_file ='
    postconf -e 'lmtp_tls_verify_cert_match = hostname'
    postconf -e 'lmtp_tls_wrappermode = no'
    postconf -e 'lmtp_transport_rate_delay = $default_transport_rate_delay'
    postconf -e 'lmtp_use_tls = no'
    postconf -e 'lmtp_xforward_timeout = 300s'
    postconf -e 'local_command_shell ='
    postconf -e 'local_delivery_slot_cost = $default_delivery_slot_cost'
    postconf -e 'local_delivery_slot_discount = $default_delivery_slot_discount'
    postconf -e 'local_delivery_slot_loan = $default_delivery_slot_loan'
    postconf -e 'local_delivery_status_filter = $default_delivery_status_filter'
    postconf -e 'local_destination_concurrency_failed_cohort_limit = $default_destination_concurrency_failed_cohort_limit'
    postconf -e 'local_destination_concurrency_limit = 2'
    postconf -e 'local_destination_concurrency_negative_feedback = $default_destination_concurrency_negative_feedback'
    postconf -e 'local_destination_concurrency_positive_feedback = $default_destination_concurrency_positive_feedback'
    postconf -e 'local_destination_rate_delay = $default_destination_rate_delay'
    postconf -e 'local_destination_recipient_limit = 1'
    postconf -e 'local_extra_recipient_limit = $default_extra_recipient_limit'
    postconf -e 'local_header_rewrite_clients = permit_inet_interfaces'
    postconf -e 'local_initial_destination_concurrency = $initial_destination_concurrency'
    postconf -e 'local_minimum_delivery_slots = $default_minimum_delivery_slots'
    postconf -e 'local_recipient_limit = $default_recipient_limit'
    postconf -e 'local_recipient_maps = proxy:unix:passwd.byname $alias_maps'
    postconf -e 'local_recipient_refill_delay = $default_recipient_refill_delay'
    postconf -e 'local_recipient_refill_limit = $default_recipient_refill_limit'
    postconf -e 'local_transport = local:$myhostname'
    postconf -e 'local_transport_rate_delay = $default_transport_rate_delay'
    postconf -e 'luser_relay ='
    postconf -e 'mail_name = Postfix'
    postconf -e 'mail_owner = postfix'
    postconf -e 'mail_release_date = 20180519'
    postconf -e 'mail_spool_directory = /var/mail'
    postconf -e 'mailbox_command_maps ='
    postconf -e 'mailbox_delivery_lock = fcntl, dotlock'
    postconf -e 'mailbox_transport ='
    postconf -e 'mailbox_transport_maps ='
    postconf -e 'mailq_path = /usr/bin/mailq'
    postconf -e 'manpage_directory = /usr/local/man'
    postconf -e 'maps_rbl_domains ='
    postconf -e 'maps_rbl_reject_code = 554'
    postconf -e 'masquerade_classes = envelope_sender, header_sender, header_recipient'
    postconf -e 'masquerade_domains ='
    postconf -e 'masquerade_exceptions ='
    postconf -e 'master_service_disable ='
    postconf -e 'max_idle = 100s'
    postconf -e 'max_use = 100'
    postconf -e 'maximal_backoff_time = 4000s'
    postconf -e 'maximal_queue_lifetime = 5d'
    postconf -e 'message_drop_headers = bcc, content-length, resent-bcc, return-path'
    postconf -e 'message_reject_characters ='
    postconf -e 'message_strip_characters ='
    postconf -e 'meta_directory = /etc/postfix'
    postconf -e 'milter_command_timeout = 30s'
    postconf -e 'milter_connect_timeout = 30s'
    postconf -e 'milter_content_timeout = 300s'
    postconf -e 'milter_data_macros = i'
    postconf -e 'milter_end_of_data_macros = i'
    postconf -e 'milter_end_of_header_macros = i'
    postconf -e 'milter_header_checks ='
    postconf -e 'milter_helo_macros = {tls_version} {cipher} {cipher_bits} {cert_subject} {cert_issuer}'
    postconf -e 'milter_macro_daemon_name = $myhostname'
    postconf -e 'milter_macro_defaults ='
    postconf -e 'milter_macro_v = $mail_name $mail_version'
    postconf -e 'milter_mail_macros = i {auth_type} {auth_authen} {auth_author} {mail_addr} {mail_host} {mail_mailer}'
    postconf -e 'milter_rcpt_macros = i {rcpt_addr} {rcpt_host} {rcpt_mailer}'
    postconf -e 'milter_unknown_command_macros ='
    postconf -e 'mime_boundary_length_limit = 2048'
    postconf -e 'mime_header_checks = $header_checks'
    postconf -e 'mime_nesting_limit = 100'
    postconf -e 'minimal_backoff_time = 300s'
    postconf -e 'multi_instance_directories ='
    postconf -e 'multi_instance_enable = no'
    postconf -e 'multi_instance_group ='
    postconf -e 'multi_instance_name ='
    postconf -e 'multi_instance_wrapper ='
    postconf -e 'multi_recipient_bounce_reject_code = 550'
    postconf -e 'mydestination = $myhostname, localhost.$mydomain, localhost'
    postconf -e 'mynetworks_style = ${{$compatibility_level} < {2} ? {subnet} : {host}}'
    postconf -e 'myorigin = $myhostname'
    postconf -e 'nested_header_checks = $header_checks'
    postconf -e 'newaliases_path = /usr/bin/newaliases'
    postconf -e 'non_fqdn_reject_code = 504'
    postconf -e 'non_smtpd_milters ='
    postconf -e 'notify_classes = resource, software'
    postconf -e 'openssl_path = openssl'
    postconf -e 'parent_domain_matches_subdomains = debug_peer_list,fast_flush_domains,mynetworks,permit_mx_backup_networks,qmqpd_authorized_clients,relay_domains,smtpd_access_maps'
    postconf -e 'permit_mx_backup_networks ='
    postconf -e 'pickup_service_name = pickup'
    postconf -e 'pipe_delivery_status_filter = $default_delivery_status_filter'
    postconf -e 'plaintext_reject_code = 450'
    postconf -e 'postmulti_control_commands = reload flush'
    postconf -e 'postmulti_start_commands = start'
    postconf -e 'postmulti_stop_commands = stop abort drain quick-stop'
    postconf -e 'postscreen_access_list = permit_mynetworks'
    postconf -e 'postscreen_bare_newline_action = ignore'
    postconf -e 'postscreen_bare_newline_enable = no'
    postconf -e 'postscreen_bare_newline_ttl = 30d'
    postconf -e 'postscreen_blacklist_action = ignore'
    postconf -e 'postscreen_cache_cleanup_interval = 12h'
    postconf -e 'postscreen_cache_map = btree:$data_directory/postscreen_cache'
    postconf -e 'postscreen_cache_retention_time = 7d'
    postconf -e 'postscreen_client_connection_count_limit = $smtpd_client_connection_count_limit'
    postconf -e 'postscreen_command_count_limit = 20'
    postconf -e 'postscreen_command_filter ='
    postconf -e 'postscreen_command_time_limit = ${stress?{10}:{300}}s'
    postconf -e 'postscreen_disable_vrfy_command = $disable_vrfy_command'
    postconf -e 'postscreen_discard_ehlo_keyword_address_maps = $smtpd_discard_ehlo_keyword_address_maps'
    postconf -e 'postscreen_discard_ehlo_keywords = $smtpd_discard_ehlo_keywords'
    postconf -e 'postscreen_dnsbl_max_ttl = ${postscreen_dnsbl_ttl?{$postscreen_dnsbl_ttl}:{1}}h'
    postconf -e 'postscreen_dnsbl_min_ttl = 60s'
    postconf -e 'postscreen_dnsbl_reply_map ='
    postconf -e 'postscreen_dnsbl_threshold = 1'
    postconf -e 'postscreen_dnsbl_timeout = 10s'
    postconf -e 'postscreen_dnsbl_whitelist_threshold = 0'
    postconf -e 'postscreen_enforce_tls = $smtpd_enforce_tls'
    postconf -e 'postscreen_expansion_filter = $smtpd_expansion_filter'
    postconf -e 'postscreen_forbidden_commands = $smtpd_forbidden_commands'
    postconf -e 'postscreen_greet_action = ignore'
    postconf -e 'postscreen_greet_banner = $smtpd_banner'
    postconf -e 'postscreen_greet_ttl = 1d'
    postconf -e 'postscreen_greet_wait = ${stress?{2}:{6}}s'
    postconf -e 'postscreen_helo_required = $smtpd_helo_required'
    postconf -e 'postscreen_non_smtp_command_action = drop'
    postconf -e 'postscreen_non_smtp_command_enable = no'
    postconf -e 'postscreen_non_smtp_command_ttl = 30d'
    postconf -e 'postscreen_pipelining_action = enforce'
    postconf -e 'postscreen_pipelining_enable = no'
    postconf -e 'postscreen_pipelining_ttl = 30d'
    postconf -e 'postscreen_post_queue_limit = $default_process_limit'
    postconf -e 'postscreen_pre_queue_limit = $default_process_limit'
    postconf -e 'postscreen_reject_footer = $smtpd_reject_footer'
    postconf -e 'postscreen_tls_security_level = $smtpd_tls_security_level'
    postconf -e 'postscreen_upstream_proxy_protocol ='
    postconf -e 'postscreen_upstream_proxy_timeout = 5s'
    postconf -e 'postscreen_use_tls = $smtpd_use_tls'
    postconf -e 'postscreen_watchdog_timeout = 10s'
    postconf -e 'postscreen_whitelist_interfaces = static:all'
    postconf -e 'prepend_delivered_header = command, file, forward'
    postconf -e 'propagate_unmatched_extensions = canonical, virtual'
    postconf -e 'proxy_interfaces ='
    postconf -e 'proxy_read_maps = $local_recipient_maps $mydestination $virtual_alias_maps $virtual_alias_domains $virtual_mailbox_maps $virtual_mailbox_domains $relay_recipient_maps $relay_domains $canonical_maps $sender_canonical_maps $recipient_canonical_maps $relocated_maps $transport_maps $mynetworks $smtpd_sender_login_maps $sender_bcc_maps $recipient_bcc_maps $smtp_generic_maps $lmtp_generic_maps $alias_maps $smtpd_client_restrictions $smtpd_helo_restrictions $smtpd_sender_restrictions $smtpd_relay_restrictions $smtpd_recipient_restrictions $address_verify_sender_dependent_default_transport_maps $address_verify_sender_dependent_relayhost_maps $address_verify_transport_maps $fallback_transport_maps $lmtp_discard_lhlo_keyword_address_maps $lmtp_pix_workaround_maps $lmtp_sasl_password_maps $lmtp_tls_policy_maps $mailbox_command_maps $mailbox_transport_maps $postscreen_discard_ehlo_keyword_address_maps $rbl_reply_maps $sender_dependent_default_transport_maps $sender_dependent_relayhost_maps $smtp_discard_ehlo_keyword_address_maps $smtp_pix_workaround_maps $smtp_sasl_password_maps $smtp_tls_policy_maps $smtpd_discard_ehlo_keyword_address_maps $smtpd_milter_maps $virtual_gid_maps $virtual_uid_maps'
    postconf -e 'proxy_write_maps = $smtp_sasl_auth_cache_name $lmtp_sasl_auth_cache_name $address_verify_map $postscreen_cache_map'
    postconf -e 'proxymap_service_name = proxymap'
    postconf -e 'proxywrite_service_name = proxywrite'
    postconf -e 'qmgr_clog_warn_time = 300s'
    postconf -e 'qmgr_daemon_timeout = 1000s'
    postconf -e 'qmgr_fudge_factor = 100'
    postconf -e 'qmgr_ipc_timeout = 60s'
    postconf -e 'qmgr_message_active_limit = 20000'
    postconf -e 'qmgr_message_recipient_limit = 20000'
    postconf -e 'qmgr_message_recipient_minimum = 10'
    postconf -e 'qmqpd_authorized_clients ='
    postconf -e 'qmqpd_client_port_logging = no'
    postconf -e 'qmqpd_error_delay = 1s'
    postconf -e 'qmqpd_timeout = 300s'
    postconf -e 'queue_directory = /var/spool/postfix'
    postconf -e 'queue_file_attribute_count_limit = 100'
    postconf -e 'queue_minfree = 0'
    postconf -e 'queue_run_delay = 300s'
    postconf -e 'queue_service_name = qmgr'
    postconf -e 'rbl_reply_maps ='
    postconf -e 'readme_directory = no'
    postconf -e 'receive_override_options ='
    postconf -e 'recipient_bcc_maps ='
    postconf -e 'recipient_canonical_classes = envelope_recipient, header_recipient'
    postconf -e 'recipient_canonical_maps ='
    postconf -e 'recipient_delimiter ='
    postconf -e 'reject_code = 554'
    postconf -e 'reject_tempfail_action = defer_if_permit'
    postconf -e 'relay_clientcerts ='
    postconf -e 'relay_delivery_slot_cost = $default_delivery_slot_cost'
    postconf -e 'relay_delivery_slot_discount = $default_delivery_slot_discount'
    postconf -e 'relay_delivery_slot_loan = $default_delivery_slot_loan'
    postconf -e 'relay_destination_concurrency_failed_cohort_limit = $default_destination_concurrency_failed_cohort_limit'
    postconf -e 'relay_destination_concurrency_limit = $default_destination_concurrency_limit'
    postconf -e 'relay_destination_concurrency_negative_feedback = $default_destination_concurrency_negative_feedback'
    postconf -e 'relay_destination_concurrency_positive_feedback = $default_destination_concurrency_positive_feedback'
    postconf -e 'relay_destination_rate_delay = $default_destination_rate_delay'
    postconf -e 'relay_destination_recipient_limit = $default_destination_recipient_limit'
    postconf -e 'relay_domains = ${{$compatibility_level} < {2} ? {$mydestination} : {}}'
    postconf -e 'relay_domains_reject_code = 554'
    postconf -e 'relay_extra_recipient_limit = $default_extra_recipient_limit'
    postconf -e 'relay_initial_destination_concurrency = $initial_destination_concurrency'
    postconf -e 'relay_minimum_delivery_slots = $default_minimum_delivery_slots'
    postconf -e 'relay_recipient_limit = $default_recipient_limit'
    postconf -e 'relay_recipient_maps ='
    postconf -e 'relay_recipient_refill_delay = $default_recipient_refill_delay'
    postconf -e 'relay_recipient_refill_limit = $default_recipient_refill_limit'
    postconf -e 'relay_transport = relay'
    postconf -e 'relay_transport_rate_delay = $default_transport_rate_delay'
    postconf -e 'relocated_maps ='
    postconf -e 'remote_header_rewrite_domain ='
    postconf -e 'require_home_directory = no'
    postconf -e 'reset_owner_alias = no'
    postconf -e 'resolve_dequoted_address = yes'
    postconf -e 'resolve_null_domain = no'
    postconf -e 'resolve_numeric_domain = no'
    postconf -e 'retry_delivery_slot_cost = $default_delivery_slot_cost'
    postconf -e 'retry_delivery_slot_discount = $default_delivery_slot_discount'
    postconf -e 'retry_delivery_slot_loan = $default_delivery_slot_loan'
    postconf -e 'retry_destination_concurrency_failed_cohort_limit = $default_destination_concurrency_failed_cohort_limit'
    postconf -e 'retry_destination_concurrency_limit = $default_destination_concurrency_limit'
    postconf -e 'retry_destination_concurrency_negative_feedback = $default_destination_concurrency_negative_feedback'
    postconf -e 'retry_destination_concurrency_positive_feedback = $default_destination_concurrency_positive_feedback'
    postconf -e 'retry_destination_rate_delay = $default_destination_rate_delay'
    postconf -e 'retry_destination_recipient_limit = $default_destination_recipient_limit'
    postconf -e 'retry_extra_recipient_limit = $default_extra_recipient_limit'
    postconf -e 'retry_initial_destination_concurrency = $initial_destination_concurrency'
    postconf -e 'retry_minimum_delivery_slots = $default_minimum_delivery_slots'
    postconf -e 'retry_recipient_limit = $default_recipient_limit'
    postconf -e 'retry_recipient_refill_delay = $default_recipient_refill_delay'
    postconf -e 'retry_recipient_refill_limit = $default_recipient_refill_limit'
    postconf -e 'retry_transport_rate_delay = $default_transport_rate_delay'
    postconf -e 'rewrite_service_name = rewrite'
    postconf -e 'sample_directory = /etc/postfix'
    postconf -e 'send_cyrus_sasl_authzid = no'
    postconf -e 'sender_bcc_maps ='
    postconf -e 'sender_canonical_classes = envelope_sender, header_sender'
    postconf -e 'sender_canonical_maps ='
    postconf -e 'sender_dependent_default_transport_maps ='
    postconf -e 'sender_dependent_relayhost_maps ='
    postconf -e 'sendmail_fix_line_endings = always'
    postconf -e 'sendmail_path = /usr/sbin/sendmail'
    postconf -e 'service_name ='
    postconf -e 'service_throttle_time = 60s'
    postconf -e 'setgid_group = postdrop'
    postconf -e 'shlib_directory = /usr/lib64/postfix'
    postconf -e 'show_user_unknown_table_name = yes'
    postconf -e 'showq_service_name = showq'
    postconf -e 'smtp_address_preference = any'
    postconf -e 'smtp_address_verify_target = rcpt'
    postconf -e 'smtp_always_send_ehlo = yes'
    postconf -e 'smtp_balance_inet_protocols = yes'
    postconf -e 'smtp_bind_address ='
    postconf -e 'smtp_bind_address6 ='
    postconf -e 'smtp_body_checks ='
    postconf -e 'smtp_cname_overrides_servername = no'
    postconf -e 'smtp_connect_timeout = 30s'
    postconf -e 'smtp_connection_cache_destinations ='
    postconf -e 'smtp_connection_cache_on_demand = yes'
    postconf -e 'smtp_connection_cache_time_limit = 2s'
    postconf -e 'smtp_connection_reuse_count_limit = 0'
    postconf -e 'smtp_connection_reuse_time_limit = 300s'
    postconf -e 'smtp_data_done_timeout = 600s'
    postconf -e 'smtp_data_init_timeout = 120s'
    postconf -e 'smtp_data_xfer_timeout = 180s'
    postconf -e 'smtp_defer_if_no_mx_address_found = no'
    postconf -e 'smtp_delivery_slot_cost = $default_delivery_slot_cost'
    postconf -e 'smtp_delivery_slot_discount = $default_delivery_slot_discount'
    postconf -e 'smtp_delivery_slot_loan = $default_delivery_slot_loan'
    postconf -e 'smtp_delivery_status_filter = $default_delivery_status_filter'
    postconf -e 'smtp_destination_concurrency_failed_cohort_limit = $default_destination_concurrency_failed_cohort_limit'
    postconf -e 'smtp_destination_concurrency_limit = $default_destination_concurrency_limit'
    postconf -e 'smtp_destination_concurrency_negative_feedback = $default_destination_concurrency_negative_feedback'
    postconf -e 'smtp_destination_concurrency_positive_feedback = $default_destination_concurrency_positive_feedback'
    postconf -e 'smtp_destination_rate_delay = $default_destination_rate_delay'
    postconf -e 'smtp_discard_ehlo_keyword_address_maps ='
    postconf -e 'smtp_discard_ehlo_keywords ='
    postconf -e 'smtp_dns_reply_filter ='
    postconf -e 'smtp_dns_resolver_options ='
    postconf -e 'smtp_dns_support_level ='
    postconf -e 'smtp_enforce_tls = no'
    postconf -e 'smtp_extra_recipient_limit = $default_extra_recipient_limit'
    postconf -e 'smtp_fallback_relay = $fallback_relay'
    postconf -e 'smtp_generic_maps ='
    postconf -e 'smtp_header_checks ='
    postconf -e 'smtp_helo_name = $myhostname'
    postconf -e 'smtp_helo_timeout = 300s'
    postconf -e 'smtp_host_lookup = dns'
    postconf -e 'smtp_initial_destination_concurrency = $initial_destination_concurrency'
    postconf -e 'smtp_line_length_limit = 998'
    postconf -e 'smtp_mail_timeout = 300s'
    postconf -e 'smtp_mime_header_checks ='
    postconf -e 'smtp_minimum_delivery_slots = $default_minimum_delivery_slots'
    postconf -e 'smtp_mx_address_limit = 5'
    postconf -e 'smtp_mx_session_limit = 2'
    postconf -e 'smtp_nested_header_checks ='
    postconf -e 'smtp_never_send_ehlo = no'
    postconf -e 'smtp_per_record_deadline = no'
    postconf -e 'smtp_pix_workaround_delay_time = 10s'
    postconf -e 'smtp_pix_workaround_maps ='
    postconf -e 'smtp_pix_workaround_threshold_time = 500s'
    postconf -e 'smtp_pix_workarounds = disable_esmtp,delay_dotcrlf'
    postconf -e 'smtp_quit_timeout = 300s'
    postconf -e 'smtp_quote_rfc821_envelope = yes'
    postconf -e 'smtp_randomize_addresses = yes'
    postconf -e 'smtp_rcpt_timeout = 300s'
    postconf -e 'smtp_recipient_limit = $default_recipient_limit'
    postconf -e 'smtp_recipient_refill_delay = $default_recipient_refill_delay'
    postconf -e 'smtp_recipient_refill_limit = $default_recipient_refill_limit'
    postconf -e 'smtp_reply_filter ='
    postconf -e 'smtp_rset_timeout = 20s'
    postconf -e 'smtp_sasl_auth_cache_name ='
    postconf -e 'smtp_sasl_auth_cache_time = 90d'
    postconf -e 'smtp_sasl_auth_enable = no'
    postconf -e 'smtp_sasl_auth_soft_bounce = yes'
    postconf -e 'smtp_sasl_mechanism_filter ='
    postconf -e 'smtp_sasl_password_maps ='
    postconf -e 'smtp_sasl_path ='
    postconf -e 'smtp_sasl_security_options = noplaintext, noanonymous'
    postconf -e 'smtp_sasl_tls_security_options = $smtp_sasl_security_options'
    postconf -e 'smtp_sasl_tls_verified_security_options = $smtp_sasl_tls_security_options'
    postconf -e 'smtp_sasl_type = cyrus'
    postconf -e 'smtp_send_dummy_mail_auth = no'
    postconf -e 'smtp_send_xforward_command = no'
    postconf -e 'smtp_sender_dependent_authentication = no'
    postconf -e 'smtp_skip_5xx_greeting = yes'
    postconf -e 'smtp_skip_quit_response = yes'
    postconf -e 'smtp_starttls_timeout = 300s'
    postconf -e 'smtp_tcp_port = smtp'
    postconf -e 'smtp_tls_block_early_mail_reply = no'
    postconf -e 'smtp_tls_cert_file ='
    postconf -e 'smtp_tls_ciphers = medium'
    postconf -e 'smtp_tls_dane_insecure_mx_policy = dane'
    postconf -e 'smtp_tls_dcert_file ='
    postconf -e 'smtp_tls_dkey_file = $smtp_tls_dcert_file'
    postconf -e 'smtp_tls_eccert_file ='
    postconf -e 'smtp_tls_eckey_file = $smtp_tls_eccert_file'
    postconf -e 'smtp_tls_enforce_peername = yes'
    postconf -e 'smtp_tls_exclude_ciphers ='
    postconf -e 'smtp_tls_fingerprint_cert_match ='
    postconf -e 'smtp_tls_fingerprint_digest = md5'
    postconf -e 'smtp_tls_force_insecure_host_tlsa_lookup = no'
    postconf -e 'smtp_tls_key_file = $smtp_tls_cert_file'
    postconf -e 'smtp_tls_loglevel = 0'
    postconf -e 'smtp_tls_mandatory_exclude_ciphers ='
    postconf -e 'smtp_tls_per_site ='
    postconf -e 'smtp_tls_policy_maps ='
    postconf -e 'smtp_tls_protocols = !SSLv2, !SSLv3'
    postconf -e 'smtp_tls_scert_verifydepth = 9'
    postconf -e 'smtp_tls_secure_cert_match = nexthop, dot-nexthop'
    postconf -e 'smtp_tls_security_level ='
    postconf -e 'smtp_tls_session_cache_database ='
    postconf -e 'smtp_tls_session_cache_timeout = 3600s'
    postconf -e 'smtp_tls_trust_anchor_file ='
    postconf -e 'smtp_tls_verify_cert_match = hostname'
    postconf -e 'smtp_tls_wrappermode = no'
    postconf -e 'smtp_transport_rate_delay = $default_transport_rate_delay'
    postconf -e 'smtp_xforward_timeout = 300s'
    postconf -e 'smtpd_authorized_verp_clients = $authorized_verp_clients'
    postconf -e 'smtpd_authorized_xclient_hosts ='
    postconf -e 'smtpd_authorized_xforward_hosts ='
    postconf -e 'smtpd_banner = $myhostname ESMTP $mail_name'
    postconf -e 'smtpd_client_auth_rate_limit = 0'
    postconf -e 'smtpd_client_connection_count_limit = 50'
    postconf -e 'smtpd_client_connection_rate_limit = 0'
    postconf -e 'smtpd_client_event_limit_exceptions = ${smtpd_client_connection_limit_exceptions:$mynetworks}'
    postconf -e 'smtpd_client_message_rate_limit = 0'
    postconf -e 'smtpd_client_new_tls_session_rate_limit = 0'
    postconf -e 'smtpd_client_port_logging = no'
    postconf -e 'smtpd_client_recipient_rate_limit = 0'
    postconf -e 'smtpd_command_filter ='
    postconf -e 'smtpd_data_restrictions ='
    postconf -e 'smtpd_delay_open_until_valid_rcpt = yes'
    postconf -e 'smtpd_discard_ehlo_keyword_address_maps ='
    postconf -e 'smtpd_discard_ehlo_keywords ='
    postconf -e 'smtpd_dns_reply_filter ='
    postconf -e 'smtpd_end_of_data_restrictions ='
    postconf -e 'smtpd_enforce_tls = no'
    postconf -e 'smtpd_etrn_restrictions ='
    postconf -e 'smtpd_forbidden_commands = CONNECT GET POST'
    postconf -e 'smtpd_hard_error_limit = ${stress?{1}:{20}}'
    postconf -e 'smtpd_helo_restrictions ='
    postconf -e 'smtpd_history_flush_threshold = 100'
    postconf -e 'smtpd_junk_command_limit = ${stress?{1}:{100}}'
    postconf -e 'smtpd_log_access_permit_actions ='
    postconf -e 'smtpd_milter_maps ='
    postconf -e 'smtpd_noop_commands ='
    postconf -e 'smtpd_null_access_lookup_key = <>'
    postconf -e 'smtpd_peername_lookup = yes'
    postconf -e 'smtpd_per_record_deadline = ${stress?{yes}:{no}}'
    postconf -e 'smtpd_policy_service_default_action = 451 4.3.5 Server configuration problem'
    postconf -e 'smtpd_policy_service_max_idle = 300s'
    postconf -e 'smtpd_policy_service_max_ttl = 1000s'
    postconf -e 'smtpd_policy_service_policy_context ='
    postconf -e 'smtpd_policy_service_request_limit = 0'
    postconf -e 'smtpd_policy_service_retry_delay = 1s'
    postconf -e 'smtpd_policy_service_timeout = 100s'
    postconf -e 'smtpd_policy_service_try_limit = 2'
    postconf -e 'smtpd_proxy_ehlo = $myhostname'
    postconf -e 'smtpd_proxy_filter ='
    postconf -e 'smtpd_proxy_options ='
    postconf -e 'smtpd_proxy_timeout = 100s'
    postconf -e 'smtpd_recipient_limit = 1000'
    postconf -e 'smtpd_recipient_overshoot_limit = 1000'
    postconf -e 'smtpd_reject_footer ='
    postconf -e 'smtpd_reject_unlisted_recipient = yes'
    postconf -e 'smtpd_reject_unlisted_sender = no'
    postconf -e 'smtpd_relay_restrictions = ${{$compatibility_level} < {1} ? {} : {permit_mynetworks, permit_sasl_authenticated, defer_unauth_destination}}'
    postconf -e 'smtpd_restriction_classes ='
    postconf -e 'smtpd_sasl_exceptions_networks ='
    postconf -e 'smtpd_sasl_local_domain ='
    postconf -e 'smtpd_sasl_path = smtpd'
    postconf -e 'smtpd_sasl_service = smtp'
    postconf -e 'smtpd_sasl_tls_security_options = $smtpd_sasl_security_options'
    postconf -e 'smtpd_sender_login_maps ='
    postconf -e 'smtpd_service_name = smtpd'
    postconf -e 'smtpd_starttls_timeout = ${stress?{10}:{300}}s'
    postconf -e 'smtpd_timeout = ${stress?{10}:{300}}s'
    postconf -e 'smtpd_tls_CAfile ='
    postconf -e 'smtpd_tls_CApath ='
    postconf -e 'smtpd_tls_always_issue_session_ids = yes'
    postconf -e 'smtpd_tls_ask_ccert = no'
    postconf -e 'smtpd_tls_auth_only = no'
    postconf -e 'smtpd_tls_ccert_verifydepth = 9'
    postconf -e 'smtpd_tls_ciphers = medium'
    postconf -e 'smtpd_tls_dcert_file ='
    postconf -e 'smtpd_tls_dh1024_param_file ='
    postconf -e 'smtpd_tls_dh512_param_file ='
    postconf -e 'smtpd_tls_dkey_file = $smtpd_tls_dcert_file'
    postconf -e 'smtpd_tls_eccert_file ='
    postconf -e 'smtpd_tls_eckey_file = $smtpd_tls_eccert_file'
    postconf -e 'smtpd_tls_eecdh_grade = auto'
    postconf -e 'smtpd_tls_exclude_ciphers ='
    postconf -e 'smtpd_tls_fingerprint_digest = md5'
    postconf -e 'smtpd_tls_mandatory_exclude_ciphers ='
    postconf -e 'smtpd_tls_protocols = !SSLv2, !SSLv3'
    postconf -e 'smtpd_tls_req_ccert = no'
    postconf -e 'smtpd_tls_session_cache_database ='
    postconf -e 'smtpd_tls_session_cache_timeout = 3600s'
    postconf -e 'smtpd_tls_wrappermode = no'
    postconf -e 'smtpd_upstream_proxy_protocol ='
    postconf -e 'smtpd_upstream_proxy_timeout = 5s'
    postconf -e 'smtputf8_autodetect_classes = sendmail, verify'
    postconf -e 'smtputf8_enable = ${{$compatibility_level} < {1} ? {no} : {yes}}'
    postconf -e 'soft_bounce = no'
    postconf -e 'stale_lock_time = 500s'
    postconf -e 'stress ='
    postconf -e 'strict_7bit_headers = no'
    postconf -e 'strict_8bitmime = no'
    postconf -e 'strict_8bitmime_body = no'
    postconf -e 'strict_mailbox_ownership = yes'
    postconf -e 'strict_mime_encoding_domain = no'
    postconf -e 'strict_smtputf8 = no'
    postconf -e 'sun_mailtool_compatibility = no'
    postconf -e 'swap_bangpath = yes'
    postconf -e 'syslog_facility = mail'
    postconf -e 'syslog_name = ${multi_instance_name?{$multi_instance_name}:{postfix}}'
    postconf -e 'tcp_windowsize = 0'
    postconf -e 'tls_append_default_CA = no'
    postconf -e 'tls_daemon_random_bytes = 32'
    postconf -e 'tls_dane_digest_agility = on'
    postconf -e 'tls_dane_digests = sha512 sha256'
    postconf -e 'tls_dane_trust_anchor_digest_enable = yes'
    postconf -e 'tls_disable_workarounds ='
    postconf -e 'tls_eecdh_auto_curves = X25519 X448 prime256v1 secp521r1 secp384r1'
    postconf -e 'tls_eecdh_strong_curve = prime256v1'
    postconf -e 'tls_eecdh_ultra_curve = secp384r1'
    postconf -e 'tls_export_cipherlist = aNULL:-aNULL:HIGH:MEDIUM:LOW:EXPORT:+RC4:@STRENGTH'
    postconf -e 'tls_high_cipherlist = aNULL:-aNULL:HIGH:@STRENGTH'
    postconf -e 'tls_legacy_public_key_fingerprints = no'
    postconf -e 'tls_low_cipherlist = aNULL:-aNULL:HIGH:MEDIUM:LOW:+RC4:@STRENGTH'
    postconf -e 'tls_medium_cipherlist = aNULL:-aNULL:HIGH:MEDIUM:+RC4:@STRENGTH'
    postconf -e 'tls_null_cipherlist = eNULL:!aNULL'
    postconf -e 'tls_preempt_cipherlist = no'
    postconf -e 'tls_random_bytes = 32'
    postconf -e 'tls_random_exchange_name = ${data_directory}/prng_exch'
    postconf -e 'tls_random_prng_update_period = 3600s'
    postconf -e 'tls_random_reseed_period = 3600s'
    postconf -e 'tls_random_source = dev:/dev/urandom'
    postconf -e 'tls_session_ticket_cipher = aes-256-cbc'
    postconf -e 'tls_ssl_options ='
    postconf -e 'tls_wildcard_matches_multiple_labels = yes'
    postconf -e 'tlsmgr_service_name = tlsmgr'
    postconf -e 'tlsproxy_enforce_tls = $smtpd_enforce_tls'
    postconf -e 'tlsproxy_service_name = tlsproxy'
    postconf -e 'tlsproxy_tls_CAfile = $smtpd_tls_CAfile'
    postconf -e 'tlsproxy_tls_CApath = $smtpd_tls_CApath'
    postconf -e 'tlsproxy_tls_always_issue_session_ids = $smtpd_tls_always_issue_session_ids'
    postconf -e 'tlsproxy_tls_ask_ccert = $smtpd_tls_ask_ccert'
    postconf -e 'tlsproxy_tls_ccert_verifydepth = $smtpd_tls_ccert_verifydepth'
    postconf -e 'tlsproxy_tls_cert_file = $smtpd_tls_cert_file'
    postconf -e 'tlsproxy_tls_ciphers = $smtpd_tls_ciphers'
    postconf -e 'tlsproxy_tls_dcert_file = $smtpd_tls_dcert_file'
    postconf -e 'tlsproxy_tls_dh1024_param_file = $smtpd_tls_dh1024_param_file'
    postconf -e 'tlsproxy_tls_dh512_param_file = $smtpd_tls_dh512_param_file'
    postconf -e 'tlsproxy_tls_dkey_file = $smtpd_tls_dkey_file'
    postconf -e 'tlsproxy_tls_eccert_file = $smtpd_tls_eccert_file'
    postconf -e 'tlsproxy_tls_eckey_file = $smtpd_tls_eckey_file'
    postconf -e 'tlsproxy_tls_eecdh_grade = $smtpd_tls_eecdh_grade'
    postconf -e 'tlsproxy_tls_exclude_ciphers = $smtpd_tls_exclude_ciphers'
    postconf -e 'tlsproxy_tls_fingerprint_digest = $smtpd_tls_fingerprint_digest'
    postconf -e 'tlsproxy_tls_key_file = $smtpd_tls_key_file'
    postconf -e 'tlsproxy_tls_loglevel = $smtpd_tls_loglevel'
    postconf -e 'tlsproxy_tls_mandatory_ciphers = $smtpd_tls_mandatory_ciphers'
    postconf -e 'tlsproxy_tls_mandatory_exclude_ciphers = $smtpd_tls_mandatory_exclude_ciphers'
    postconf -e 'tlsproxy_tls_mandatory_protocols = $smtpd_tls_mandatory_protocols'
    postconf -e 'tlsproxy_tls_protocols = $smtpd_tls_protocols'
    postconf -e 'tlsproxy_tls_req_ccert = $smtpd_tls_req_ccert'
    postconf -e 'tlsproxy_tls_security_level = $smtpd_tls_security_level'
    postconf -e 'tlsproxy_use_tls = $smtpd_use_tls'
    postconf -e 'tlsproxy_watchdog_timeout = 10s'
    postconf -e 'trace_service_name = trace'
    postconf -e 'transport_maps ='
    postconf -e 'transport_retry_time = 60s'
    postconf -e 'trigger_timeout = 10s'
    postconf -e 'undisclosed_recipients_header ='
    postconf -e 'unknown_address_reject_code = 450'
    postconf -e 'unknown_address_tempfail_action = $reject_tempfail_action'
    postconf -e 'unknown_client_reject_code = 450'
    postconf -e 'unknown_helo_hostname_tempfail_action = $reject_tempfail_action'
    postconf -e 'unknown_hostname_reject_code = 450'
    postconf -e 'unknown_local_recipient_reject_code = 550'
    postconf -e 'unknown_relay_recipient_reject_code = 550'
    postconf -e 'unknown_virtual_alias_reject_code = 550'
    postconf -e 'unknown_virtual_mailbox_reject_code = 550'
    postconf -e 'unverified_recipient_defer_code = 450'
    postconf -e 'unverified_recipient_reject_code = 450'
    postconf -e 'unverified_recipient_reject_reason ='
    postconf -e 'unverified_recipient_tempfail_action = $reject_tempfail_action'
    postconf -e 'unverified_sender_defer_code = 450'
    postconf -e 'unverified_sender_reject_code = 450'
    postconf -e 'unverified_sender_reject_reason ='
    postconf -e 'unverified_sender_tempfail_action = $reject_tempfail_action'
    postconf -e 'verp_delimiter_filter = -=+'
    postconf -e 'virtual_alias_address_length_limit = 1000'
    postconf -e 'virtual_alias_expansion_limit = 1000'
    postconf -e 'virtual_alias_recursion_limit = 1000'
    postconf -e 'virtual_delivery_slot_cost = $default_delivery_slot_cost'
    postconf -e 'virtual_delivery_slot_discount = $default_delivery_slot_discount'
    postconf -e 'virtual_delivery_slot_loan = $default_delivery_slot_loan'
    postconf -e 'virtual_delivery_status_filter = $default_delivery_status_filter'
    postconf -e 'virtual_destination_concurrency_failed_cohort_limit = $default_destination_concurrency_failed_cohort_limit'
    postconf -e 'virtual_destination_concurrency_limit = $default_destination_concurrency_limit'
    postconf -e 'virtual_destination_concurrency_negative_feedback = $default_destination_concurrency_negative_feedback'
    postconf -e 'virtual_destination_concurrency_positive_feedback = $default_destination_concurrency_positive_feedback'
    postconf -e 'virtual_destination_rate_delay = $default_destination_rate_delay'
    postconf -e 'virtual_destination_recipient_limit = $default_destination_recipient_limit'
    postconf -e 'virtual_extra_recipient_limit = $default_extra_recipient_limit'
    postconf -e 'virtual_gid_maps ='
    postconf -e 'virtual_initial_destination_concurrency = $initial_destination_concurrency'
    postconf -e 'virtual_mailbox_base ='
    postconf -e 'virtual_mailbox_domains = $virtual_mailbox_maps'
    postconf -e 'virtual_mailbox_limit = 51200000'
    postconf -e 'virtual_mailbox_lock = fcntl, dotlock'
    postconf -e 'virtual_mailbox_maps ='
    postconf -e 'virtual_minimum_delivery_slots = $default_minimum_delivery_slots'
    postconf -e 'virtual_minimum_uid = 100'
    postconf -e 'virtual_recipient_limit = $default_recipient_limit'
    postconf -e 'virtual_recipient_refill_delay = $default_recipient_refill_delay'
    postconf -e 'virtual_recipient_refill_limit = $default_recipient_refill_limit'
    postconf -e 'virtual_transport = virtual'
    postconf -e 'virtual_transport_rate_delay = $default_transport_rate_delay'
    postconf -e 'virtual_uid_maps ='
    #postconf -e 'smtpd_expansion_filter = \t\40!"#$%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_`abcdefghijklmnopqrstuvwxyz{|}~'
fi


# Perform Postfix restart:
if [ "$POSTFIXUP" -eq "1" ];then
    /usr/bin/systemctl restart postfix >/dev/null 2>&1 || :
fi

# 
# Copyright (c) 2020 Michael Stauber, SOLARSPEED.NET
# Copyright (c) 2020 Team BlueOnyx, BLUEONYX.IT
# All Rights Reserved.
# 
# 1. Redistributions of source code must retain the above copyright 
#    notice, this list of conditions and the following disclaimer.
# 
# 2. Redistributions in binary form must reproduce the above copyright 
#    notice, this list of conditions and the following disclaimer in 
#    the documentation and/or other materials provided with the 
#    distribution.
# 
# 3. Neither the name of the copyright holder nor the names of its 
#    contributors may be used to endorse or promote products derived 
#    from this software without specific prior written permission.
# 
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
# FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
# COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
# BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
# CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.
# 
# You acknowledge that this software is not designed or intended for 
# use in the design, construction, operation or maintenance of any 
# nuclear facility.
# 
